package config

import (
	"encoding/json"
	"os"
	"sync"

	"github.com/sirupsen/logrus"
)

var once sync.Once

func Load(cfg interface{}) {
	once.Do(func() {
		configPath, found := os.LookupEnv("CONFIG_PATH")
		if !found {
			logrus.Fatal("env CONFIG_PATH missing")
		}

		file, err := os.Open(configPath)
		if err != nil {
			logrus.
				WithField("config-path", configPath).
				WithError(err).
				Fatal("could not open config file")
		}

		if err := json.NewDecoder(file).Decode(cfg); err != nil {
			logrus.
				WithError(err).
				Fatal("unable to decode config from file")
		}
	})
}
